@@ -120,6 +120,10 @@ class Ids:
                 self._identity_store_id = identity_store_id
         return self._instance_arn
 
+    @property
+    def instance_id(self):
+        return self.instance_arn.split("/", 1)[1]
+
     @property
     def identity_store_id(self):
         if self._identity_store_id:
